@@ -74,10 +74,13 @@ CREATE TABLE account
   -- Indicate whether the password of the user never expires.
   does_password_never_expire boolean NOT NULL DEFAULT true,
 
-  -- Identification of the picture of this user account, also known as the
-  -- avatar, which is the graphical representation of the user.
+  -- The identification of the picture of the user account, whether the
+  -- graphical representation of the user (avatar) or their photo ID.
   picture_id uuid NULL,
 
+  -- The time when the user's picture was taken.
+  picture_time timestamptz(3) NULL
+
   -- A locale that references the preferred language of the user.  A
   -- locale is expressed by a ISO 639-3 alpha-3 code element, optionally
   -- followed by a dash character "-" and a ISO 3166-1 alpha-2 code.  For
@@ -445,14 +448,17 @@ CREATE TABLE account_picture
   -- The identification of the user account that the picture is associated
   -- with.
   --
-  -- @note: This column is null when a user account is hard-deleted.  A
+  -- @note: This column is null when the user account was hard-deleted.  A
   --     clean-up process will delete the files of all orphan pictures,
   --     before deleting the corresponding records.
   account_id uuid NULL,
 
   -- The identification of the account of the user who submitted the
   -- picture.
-  submitter_account_id uuid NOT NULL,
+  --
+  -- @note: This column is null when the submitter user account is hard-
+  --     deleted.
+  submitter_account_id uuid NULL,
 
   -- The identification of the organization of the user who submitted the
   -- picture.
@@ -467,8 +473,8 @@ CREATE TABLE account_picture
   -- The size in bytes of the user's original photo image file.
   image_file_size int NOT NULL,
 
-  -- The message digest of the the binary data of the user's original
-  -- photo image file.
+  -- The message digest of the binary data of the user's original photo
+  -- image file.
   image_file_checksum text NOT NULL,
 
   -- Indicate whether the picture needs to be reviewed by someone who has
@@ -478,6 +484,30 @@ CREATE TABLE account_picture
   -- Identification of the client application that uploaded the picture.
   app_id uuid NOT NULL,
 
+  -- The exception describing the reason for which the picture may have
+  -- been rejected:
+  --
+  -- * `NoFaceDetectedException`: No face has been detected in the photo.
+  --
+  -- * `MultipleFacesDetectedException``: Multiple faces have been detected
+  --   in the photo.
+  --
+  -- * `MissingFaceFeaturesException` Some features are missing from the
+  --   detected face.
+  --
+  -- * `ObliqueFacePoseException`: The head doesn't face the camera straight
+  --   on.
+  --
+  -- * `OpenedMouthOrSmileException`: The mouth is not closed or with a
+  --   smile.
+  --
+  -- * `AbnormalEyelidOpeningStateException`: An eyelid is widely opened,
+  --   narrowed or closed.
+  --
+  -- * `UnevenlyOpenEyelidException`: A eye is more opened/closed than the
+  --   other.
+  rejection_exception NULL,
+
   -- The current status of the picture.
   object_status text NOT NULL DEFAULT +object-status-pending+,
 
