@@ -30,6 +30,8 @@ import uuid
 from majormode.perseus.constant.application import ApplicationPlatform
 from majormode.perseus.constant.application import ApplicationStage
 from majormode.perseus.constant.obj import ObjectStatus
+from majormode.perseus.utils.rdbms import RdbmsConnection
+
 from majormode.perseus.service.account.account_service import AccountService
 from majormode.perseus.service.base_rdbms_service import BaseRdbmsService
 from majormode.perseus.service.base_service import BaseService
@@ -90,7 +92,7 @@ class ApplicationService(BaseRdbmsService):
         :raise IllegalAccessException: If the user specified by his account is
            not an administrator of the application.
         """
-        application = self.get_application(app_id, check_status=True)
+        application = self.get_application_with_id(app_id, check_status=True)
         if application.team_id is None:
             if account_id != application.account_id:
                 raise self.IllegalAccessException()
@@ -114,7 +116,75 @@ class ApplicationService(BaseRdbmsService):
             cls.CDN_BUCKET_NAME_PICTURE,
             str(picture_id))
 
-    def get_application(
+    def get_application_with_consumer_key(
+            self,
+            consumer_key: str,
+            check_status: bool = False,
+            connection: RdbmsConnection = None):
+        """
+        Return information about an application providing a consumer key.
+
+
+        @param consumer_key: Application Programming Interface (API) key tied
+            to the application that accesses the service.
+
+        @param check_status: Indicate whether to check the status of the
+            Consumer Key.
+
+        @param connection: An existing connection to the API keys database.
+
+
+        @return: An object containing the following attributes:
+
+            - `app_id: UUID` (required): The identification of the application.
+
+            - `consumer_secret` (required): A string kept secret used to authenticate
+              the API Consumer Key.
+
+            - `stage: ApplicationStage` (required): The environment stage which the
+              application is deployed onto.
+
+            - `object_status: ObjectStatus` (required): The current status of the
+              Consumer Key.
+        """
+        with self.acquire_rdbms_connection(auto_commit=False, connection=connection) as connection:
+            cursor = connection.execute(
+                """
+                SELECT 
+                    app_id,
+                    consumer_secret,
+                    stage,
+                    object_status
+                  FROM
+                    application
+                  WHERE
+                    consumer_key = %(consumer_key)s
+                """,
+                {
+                    'consumer_key': consumer_key
+                }
+            )
+
+            row = cursor.fetch_one()
+            if row is None:
+                raise self.UndefinedObjectException(f"Undefined API consumer key {consumer_key}")
+
+            application = row.get_object({
+                'app_id': cast.string_to_uuid,
+                'object_status': ObjectStatus,
+                'stage': ApplicationStage,
+            })
+
+        # Check the current status of the application.
+        if check_status:
+            if application.object_status == ObjectStatus.deleted:
+                raise ApplicationService.DeletedObjectException(f"The API consumer key {consumer_key} has been deleted")
+            elif application.object_status == ObjectStatus.disabled:
+                raise ApplicationService.DisabledObjectException(f"The API consumer key {consumer_key} has been disabled")
+
+        return application
+
+    def get_application_with_id(
             self,
             app_id,
             check_status=False,
@@ -275,7 +345,7 @@ class ApplicationService(BaseRdbmsService):
             notification to a user to whatever version(s) and platform(s) he
             could use.
 
-        :param stage: An item of ``ApplicationStage`` that indicates the
+        :param stage: An item of `ApplicationStage` that indicates the
             environment stage which the application is deployed onto.
 
         :param team_id: Identification of a team this application belongs to.
@@ -411,11 +481,10 @@ class ApplicationService(BaseRdbmsService):
 
     def validate_signature(
             self,
-            consumer_key,
-            path_query_string,
-            message_body,
-            api_sig=None,
-            strict=True):
+            app_info: any,
+            path_query_string: str,
+            message_body: bin,
+            api_sig: str = None):
         """
         Check whether the Uniform Resource Locator (URL) specified in a HTTP
         request performed by a client application against the platform, is
@@ -423,123 +492,84 @@ class ApplicationService(BaseRdbmsService):
         client application.
 
 
-        :param consumer_key: Application Programming Interface (API) key tied
-            to the application that accesses the service.
+        @param app_info: An object containing the following information about
+            the application:
 
-        :param path_query_string: Path and query string of the HTTP request
+            - `app_id: UUID` (required): The identification of the application.
+
+            - `consumer_secret` (required): A string kept secret used to authenticate
+              the API Consumer Key.
+
+            - `stage: ApplicationStage` (required): The environment stage which the
+              application is deployed onto.
+
+        @param path_query_string: Path and query string of the HTTP request
             that the application must have signed with its API secret key.
 
-        :param message_body: Content of the HTTP request message body, or
-            ``None`` if no message body has been passed along with the HTTP
+        @param message_body: Content of the HTTP request message body, or
+            `None` if no message body has been passed along with the HTTP
             request.
 
-        :param api_sig: Signature of the HTTP request as calculated by the
+        @param api_sig: Signature of the HTTP request as calculated by the
             client application.
 
-        :param strict: Indicate whether the signature has to be verified or if
-            the function should only checked that the application is at least
-            enabled.  For instance, development environments should not require
-            HTTP requests to be signed so that developers can easily debug them
-            through command line tools such as cURL.
+
+        @return: The identification of the application.
 
 
-        :return: The identification of the application.
-
-
-        :raise DeletedObjectException: If the specified API key has been
+        @raise DeletedObjectException: If the specified API key has been
             deleted, and as such, it cannot be used or referenced anymore.
 
-        :raise DisabledObjectException: If the specified API key has been
+        @raise DisabledObjectException: If the specified API key has been
             disabled, and as such, it cannot be used anymore
 
-        :raise IncorrectSignatureException: If the HTTP request has not been
+        @raise IncorrectSignatureException: If the HTTP request has not been
             signed while the signature is required (production stage) or
             requested (argument ``strict``), or if the signature of the HTTP
             request is incorrect.  The API Secret Key that has been used to
             sign the request might no correspond to the associated API
             Consumer Key.
 
-        :raise UndefinedObjectException: If the specified API key has not been
+        @raise UndefinedObjectException: If the specified API key has not been
             registered against the platform.
         """
-        # Retrieve information about the application.
-        with self.acquire_rdbms_connection() as connection:
-            cursor = connection.execute(
-                """
-                SELECT 
-                    app_id,
-                    consumer_secret,
-                    stage,
-                    object_status
-                  FROM
-                    application
-                  WHERE
-                    consumer_key = %(consumer_key)s
-                """,
-                {
-                    'consumer_key': consumer_key
-                }
-            )
-            row = cursor.fetch_one()
-            if row is None:
-                raise self.UndefinedObjectException(f"Undefined API consumer key {consumer_key}")
+        # Replace %xx escapes from the query string with their single-character
+        # equivalent.  Client applications generally build query string without
+        # escaping special characters, while the HTTP library they used will do
+        # encode them behind the scene.
+        #
+        # For example, one client application prepare and sign the following URL:
+        #
+        # ```url
+        # /school/child?limit=100&offset=0&sync_time=2020-10-15T09:55:52.108+07:00'
+        # ```
+        #
+        # But, its HTTP library encodes and sends to the RESTful API server the
+        # following URL:
+        #
+        # ```url
+        # /school/child?limit=100&offset=0&sync_time=2020-10-15T09%3A55%3A52.108%2B07%3A00"
+        # ```
+        message = urllib.parse.unquote(path_query_string)
 
-            application = row.get_object({
-                'app_id': cast.string_to_uuid,
-                'object_status': ObjectStatus,
-                'stage': ApplicationStage})
+        # Add the decoded version of the message body, if any.
+        if message_body is not None:
+            message += message_body.decode()
 
-        # Check the current status of the application.
-        if application.object_status == ObjectStatus.deleted:
-            raise ApplicationService.DeletedObjectException(f"The API consumer key {consumer_key} has been deleted")
-        elif application.object_status == ObjectStatus.disabled:
-            raise ApplicationService.DisabledObjectException(f"The API consumer key {consumer_key} has been disabled")
+        digest = hmac \
+            .new(
+                app_info.consumer_secret.encode(),
+                msg=message.encode(),
+                digestmod=ApplicationService.CRYPTOGRAPHIC_HASH_FUNCTION) \
+            .hexdigest()
 
-        # Check whether the HTTP request signature is required.
-        if (application.stage == ApplicationStage.live or strict) and api_sig is None:
-            raise self.IncorrectSignatureException('Undefined HTTP request signature')
-
-        # Check whether the HTTP request signature is valid.
-        if api_sig:
-            # Replace %xx escapes from the query string with their single-character
-            # equivalent.  Client applications generally build query string without
-            # escaping special characters, while the HTTP library they used will do
-            # encode them behind the scene.
-            #
-            # For example, one client application prepare and sign the following URL:
-            #
-            # ```url
-            # /school/child?limit=100&offset=0&sync_time=2020-10-15T09:55:52.108+07:00'
-            # ```
-            #
-            # But, its HTTP library encodes and sends to the RESTful API server the
-            # following URL:
-            #
-            # ```url
-            # /school/child?limit=100&offset=0&sync_time=2020-10-15T09%3A55%3A52.108%2B07%3A00"
-            # ```
-            message = urllib.parse.unquote(path_query_string)
-
-            # Add the decoded version of the message body, if any.
-            if message_body is not None:
-                message += message_body.decode()
-
-            digest = hmac \
-                .new(
-                    application.consumer_secret.encode(),
-                    msg=message.encode(),
-                    digestmod=ApplicationService.CRYPTOGRAPHIC_HASH_FUNCTION) \
-                .hexdigest()
-
-            if api_sig.lower() != digest:
-                logging.debug(f'Path query string: "{path_query_string}"')
-                logging.debug(f'Message body: "{"" if message_body is None else message_body.decode()}"')
-                logging.debug(f'Encoded message: "{message}"')
-                logging.debug(f'Expected signature: "{digest}"')
-                logging.debug(f'Client signature: "{api_sig.lower()}"')
-                raise ApplicationService.IncorrectSignatureException("Invalid HTTP request signature")
-
-        return application.app_id
+        if api_sig.lower() != digest:
+            logging.debug(f'Path query string: "{path_query_string}"')
+            logging.debug(f'Message body: "{"" if message_body is None else message_body.decode()}"')
+            logging.debug(f'Encoded message: "{message}"')
+            logging.debug(f'Expected signature: "{digest}"')
+            logging.debug(f'Client signature: "{api_sig.lower()}"')
+            raise ApplicationService.IncorrectSignatureException("Invalid HTTP request signature")
 
     # def update_application(self, app_id, account_id, this_app_id, properties):
     #     """
